/*
 * (C) Copyright 2007 Tundra Semiconductor Corp.
 * http://www.tundra.com/Support/SupportForm.cfm
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

/*-----------------------------------------------------------------------------
* FILENAME: ts_ge.h
*
* DESCRIPTION: Header file contains the TSI110 GE port register definitions
*              and bitmasks
* HISTORY:
*
*    Rev. Date           Author          Description
*    ---- ------------   -------------   --------------------------------------
*         Apr 27, 2007   Jason McKenna   Improve formatting
*         Mar 14, 2007   Jason McKenna   Original release.
*----------------------------------------------------------------------------*/


#ifndef _TS_GE_H_
#define _TS_GE_H_
/* *********************************************/
/* GE : Register address offset definitions    */
/* *********************************************/

/* NOTE: Valid EY values E0, E1*/
#define MAX_E_PORTS					2

#define GE_EY_MAC_CONFIGURATION1			(0x000)
#define GE_EY_MAC_CONFIGURATION2			(0x004)
#define GE_EY_IPG_IFG					(0x008)
#define GE_EY_HALF_DUPLEX				(0x00c)
#define GE_EY_MAXIMUM_FRAME_LENGTH			(0x010)
#define GE_EY_TEST_REGISTER				(0x01c)
#define GE_EY_MII_MGMT_CONFIGURATION			(0x020)
#define GE_EY_MII_MGMT_COMMAND				(0x024)
#define GE_EY_MII_MGMT_ADDRESS				(0x028)
#define GE_EY_MII_MGMT_CONTROL				(0x02c)
#define GE_EY_MII_MGMT_STATUS				(0x030)
#define GE_EY_MII_MGMT_INDICATORS			(0x034)
#define GE_EY_UNUSED					(0x038)
#define GE_EY_INTERFACE_STATUS				(0x03c)
#define GE_EY_STATION_ADDRESS1				(0x040)
#define GE_EY_STATION_ADDRESS2				(0x044)
#define GE_EY_TR64					(0x050)
#define GE_EY_TR127					(0x054)
#define GE_EY_TR255					(0x058)
#define GE_EY_TR511					(0x05c)
#define GE_EY_TR1K					(0x060)
#define GE_EY_TRMAX					(0x064)
#define GE_EY_TRMGV					(0x068)
#define GE_EY_RBYT					(0x06c)
#define GE_EY_RPKT					(0x070)
#define GE_EY_RFCS					(0x074)
#define GE_EY_RMCA					(0x078)
#define GE_EY_RBCA					(0x07c)
#define GE_EY_RXCF					(0x080)
#define GE_EY_RXPF					(0x084)
#define GE_EY_RXUO					(0x088)
#define GE_EY_RALN					(0x08c)
#define GE_EY_RFLR					(0x090)
#define GE_EY_RCDE					(0x094)
#define GE_EY_RCSE					(0x098)
#define GE_EY_RUND					(0x09c)
#define GE_EY_ROVR					(0x0a0)
#define GE_EY_RFRG					(0x0a4)
#define GE_EY_RJBR					(0x0a8)
#define GE_EY_RDRP					(0x0ac)
#define GE_EY_TBYT					(0x0b0)
#define GE_EY_TPKT					(0x0b4)
#define GE_EY_TMCA					(0x0b8)
#define GE_EY_TBCA					(0x0bc)
#define GE_EY_TXPF					(0x0c0)
#define GE_EY_TDFR					(0x0c4)
#define GE_EY_TEDF					(0x0c8)
#define GE_EY_TSCL					(0x0cc)
#define GE_EY_TMCL					(0x0d0)
#define GE_EY_TLCL					(0x0d4)
#define GE_EY_TXCL					(0x0d8)
#define GE_EY_TNCL					(0x0dc)
#define GE_EY_TPFH					(0x0e0)
#define GE_EY_TDRP					(0x0e4)
#define GE_EY_TJBR					(0x0e8)
#define GE_EY_TFCS					(0x0ec)
#define GE_EY_TXCF					(0x0f0)
#define GE_EY_TOVR					(0x0f4)
#define GE_EY_TUND					(0x0f8)
#define GE_EY_TFRG					(0x0fc)
#define GE_EY_CAR1					(0x100)
#define GE_EY_CAR2					(0x104)
#define GE_EY_CAM1					(0x108)
#define GE_EY_CAM2					(0x10c)
#define GE_EY_PORT_CONTROL				(0x200)
#define GE_EY_PORT_INT_STATUS				(0x204)
#define GE_EY_PORT_INT_MASK				(0x208)
#define GE_EY_OCN_STATUS				(0x20c)

#define GE_EY_TX_CONFIGURATION				(0x220)
#define GE_EY_TX_CONTROL				(0x224)
#define GE_EY_TX_STATUS					(0x228)
#define GE_EY_TX_EXTENDED_STATUS			(0x22c)
#define GE_EY_TX_THRESHOLDS				(0x230)
#define GE_EY_TX_PRIORITY_THRESHOLDS			(0x234)
#define GE_EY_TX_QUEUE_PRIORITY_MAP			(0x240)
#define GE_EY_TX_PENDING_COMPLETION			(0x248)
#define GE_EY_TX_PAUSE_COUNT				(0x250)
#define GE_EY_TX_GLOBAL_VLAN_TAG			(0x254)
#define GE_EY_TX_DIAGNOSTIC_INDIRECT_ADDRESS		(0x270)
#define GE_EY_TX_DIAGNOSTIC_INDIRECT_DATA		(0x274)
#define GE_EY_TX_ERROR_STATUS				(0x278)

#define GE_EY_TX_QUEUE_N_CONFIGURATION(n)		(0x280 + 0x10*(n))
#define GE_EY_TX_QUEUE_N_BUFFER_CONFIG(n)		(0x284 + 0x10*(n))
#define GE_EY_TX_QUEUE_N_PTR_LOW(n)			(0x288 + 0x10*(n))
#define GE_EY_TX_QUEUE_N_PTR_HIGH(n)			(0x28c + 0x10*(n))

#define GE_EY_RX_CONFIGURATION				(0x320)
#define GE_EY_RX_CONTROL				(0x324)
#define GE_EY_RX_STATUS					(0x328)
#define GE_EY_RX_EXTENDED_STATUS			(0x32c)
#define GE_EY_RX_PAUSE_THRESHOLDS			(0x330)
#define GE_EY_RX_THRESHOLD				(0x334)
#define GE_EY_RX_VLAN_TAG_MAP				(0x340)
#define GE_EY_RX_HASH_TABLE_INDIRECT_ADDRESS		(0x360)
#define GE_EY_RX_HASH_TABLE_INDIRECT_DATA		(0x364)
#define GE_EY_RX_DIAGNOSTIC_INDIRECT_ADDRESS		(0x370)
#define GE_EY_RX_DIAGNOSTIC_INDIRECT_DATA		(0x374)
#define GE_EY_RX_ERROR_STATUS				(0x378)

#define GE_EY_RX_QUEUE_N_CONFIGURATION(n)		(0x380 + 0x10*(n))
#define GE_EY_RX_QUEUE_N_BUFFER_CONFIGURATION(n)	(0x384 + 0x10*(n))
#define GE_EY_RX_QUEUE_N_POINTER_LOW(n)			(0x388 + 0x10*(n))
#define GE_EY_RX_QUEUE_N_POINTER_HIGH(n)		(0x38c + 0x10*(n))

/* ************************************************ */
/* GE : Register Bit Masks and Reset Values    */
/*           definitions for every register         */
/* ************************************************ */

/* GE_EY_MAC_CONFIGURATION1 : Register Bits Masks Definitions */
#define GE_EY_MAC_CONFIGURATION1_TX_ENABLE		(0x00000001)
#define GE_EY_MAC_CONFIGURATION1_SYNC_TX_ENABLE		(0x00000002)
#define GE_EY_MAC_CONFIGURATION1_RX_ENABLE		(0x00000004)
#define GE_EY_MAC_CONFIGURATION1_SYNC_RX_ENABLE		(0x00000008)
#define GE_EY_MAC_CONFIGURATION1_TX_FLOW_CONTROL	(0x00000010)
#define GE_EY_MAC_CONFIGURATION1_RX_FLOW_CONTROL	(0x00000020)
#define GE_EY_MAC_CONFIGURATION1_LOOP_BACK		(0x00000100)
#define GE_EY_MAC_CONFIGURATION1_RESET_TX_FUNCTION	(0x00010000)
#define GE_EY_MAC_CONFIGURATION1_RESET_RX_FUNCTION	(0x00020000)
#define GE_EY_MAC_CONFIGURATION1_RESET_TX_MAC		(0x00040000)
#define GE_EY_MAC_CONFIGURATION1_RESET_RX_MAC		(0x00080000)
#define GE_EY_MAC_CONFIGURATION1_SIM_RESET		(0x40000000)
#define GE_EY_MAC_CONFIGURATION1_SOFT_RESET		(0x80000000)
#define GE_EY_MAC_CONFIGURATION1_RESERVED		(0x3ff0fec0)

/* GE_EY_MAC_CONFIGURATION2 : Register Bits Masks Definitions */
#define GE_EY_MAC_CONFIGURATION2_FULL_DUPLEX		(0x00000001)
#define GE_EY_MAC_CONFIGURATION2_CRC_ENABLE		(0x00000002)
#define GE_EY_MAC_CONFIGURATION2_PAD_CRC		(0x00000004)
#define GE_EY_MAC_CONFIGURATION2_LENGTH_CHECK		(0x00000010)
#define GE_EY_MAC_CONFIGURATION2_HUGE_FRAME		(0x00000020)
#define GE_EY_MAC_CONFIGURATION2_INTERFACE_MODE		(0x00000300)
#define GE_EY_MAC_CONFIGURATION2_PREAMBLE_LENGTH	(0x0000f000)
#define GE_EY_MAC_CONFIGURATION2_RESERVED		(0xffff0cc8)

/* GE_EY_IPG_IFG : Register Bits Masks Definitions */
#define GE_EY_IPG_IFG_BACK_TO_BACK_INTER_PACKET_GAP	(0x0000007f)
#define GE_EY_IPG_IFG_MINIMUM_IFG_ENFORCEMENT		(0x0000ff00)
#define GE_EY_IPG_IFG_NON_BACK_TO_BACK_INTER_PACKET_GAP_PART_2 (0x007f0000)
#define GE_EY_IPG_IFG_NON_BACK_TO_BACK_INTER_PACKET_GAP_PART_1 (0x7f000000)
#define GE_EY_IPG_IFG_RESERVED				(0x80800080)

/* GE_EY_HALF_DUPLEX : Register Bits Masks Definitions */
#define GE_EY_HALF_DUPLEX_COLLISION_WINDOW		(0x000003ff)
#define GE_EY_HALF_DUPLEX_RETRANSMISSION_MAXIMUM	(0x0000f000)
#define GE_EY_HALF_DUPLEX_EXCESSIVE_DEFER		(0x00010000)
#define GE_EY_HALF_DUPLEX_NO_BACKOFF			(0x00020000)
#define GE_EY_HALF_DUPLEX_BP_NO_BACKOFF			(0x00040000)
#define GE_EY_HALF_DUPLEX_ALT_BEB_ENABLE		(0x00080000)
#define GE_EY_HALF_DUPLEX_ALT_BEB_TRUNCATION		(0x00f00000)
#define GE_EY_HALF_DUPLEX_RESERVED			(0xff000c00)

/* GE_EY_MAXIMUM_FRAME_LENGTH : Register Bits Masks Definitions */
#define GE_EY_MAXIMUM_FRAME_LENGTH_MAXIMUM_FRAME_LEN	(0x0000ffff)
#define GE_EY_MAXIMUM_FRAME_LENGTH_RESERVED		(0xffff0000)

/* GE_EY_TEST_REGISTER : Register Bits Masks Definitions */
#define GE_EY_TEST_REGISTER_SHORTCUT_SLOT_TIME		(0x00000001)
#define GE_EY_TEST_REGISTER_TEST_PAUSE			(0x00000002)
#define GE_EY_TEST_REGISTER_REG_TX_HD_FLOW		(0x00000004)
#define GE_EY_TEST_REGISTER_MAX_BACK_OFF		(0x00000008)
#define GE_EY_TEST_REGISTER_RESERVED			(0xfffffff0)

/* GE_EY_MII_MGMT_CONFIGURATION : Register Bits Masks Definitions */
#define GE_EY_MII_MGMT_CONFIGURATION_MGMT_CLOCK_SELECT	(0x00000007)
#define GE_EY_MII_MGMT_CONFIGURATION_NO_PREAMBLE	(0x00000010)
#define GE_EY_MII_MGMT_CONFIGURATION_SCAN_INCREMENT	(0x00000020)
#define GE_EY_MII_MGMT_CONFIGURATION_RESET_MGMT		(0x80000000)
#define GE_EY_MII_MGMT_CONFIGURATION_RESERVED		(0x7fffffc8)

/* GE_EY_MII_MGMT_COMMAND : Register Bits Masks Definitions */
#define GE_EY_MII_MGMT_COMMAND_READ_CYCLE		(0x00000001)
#define GE_EY_MII_MGMT_COMMAND_SCAN_CYCLE		(0x00000002)
#define GE_EY_MII_MGMT_COMMAND_RESERVED			(0xfffffffc)

/* GE_EY_MII_MGMT_ADDRESS : Register Bits Masks Definitions */
#define GE_EY_MII_MGMT_ADDRESS_REGISTER_ADDRESS		(0x0000001f)
#define GE_EY_MII_MGMT_ADDRESS_PHY_ADDRESS		(0x00001f00)
#define GE_EY_MII_MGMT_ADDRESS_RESERVED			(0xffffe0e0)

/* GE_EY_MII_MGMT_CONTROL : Register Bits Masks Definitions */
#define GE_EY_MII_MGMT_CONTROL_PHY_CONTROL		(0x0000ffff)
#define GE_EY_MII_MGMT_CONTROL_RESERVED			(0xffff0000)

/* GE_EY_MII_MGMT_STATUS : Register Bits Masks Definitions */
#define GE_EY_MII_MGMT_STATUS_PHY_STATUS		(0x0000ffff)
#define GE_EY_MII_MGMT_STATUS_RESERVED			(0xffff0000)

/* GE_EY_MII_MGMT_INDICATORS : Register Bits Masks Definitions */
#define GE_EY_MII_MGMT_INDICATORS_BUSY			(0x00000001)
#define GE_EY_MII_MGMT_INDICATORS_SCAN			(0x00000002)
#define GE_EY_MII_MGMT_INDICATORS_NOT_VALID		(0x00000004)
#define GE_EY_MII_MGMT_INDICATORS_RESERVED		(0xfffffff8)

/* GE_EY_INTERFACE_STATUS : Register Bits Masks Definitions */
#define GE_EY_INTERFACE_STATUS_LINK_FAIL		(0x00000008)
#define GE_EY_INTERFACE_STATUS_EXCESS_DEFER		(0x00000200)
#define GE_EY_INTERFACE_STATUS_RESERVED			(0xfffffdf7)

/* GE_EY_STATION_ADDRESS1 : Register Bits Masks Definitions */
#define GE_EY_STATION_ADDRESS1_STATION_ADDRESS_4TH_OCTET (0x000000ff)
#define GE_EY_STATION_ADDRESS1_STATION_ADDRESS_3RD_OCTET (0x0000ff00)
#define GE_EY_STATION_ADDRESS1_STATION_ADDRESS_2ND_OCTET (0x00ff0000)
#define GE_EY_STATION_ADDRESS1_STATION_ADDRESS_1ST_OCTET (0xff000000)

/* GE_EY_STATION_ADDRESS2 : Register Bits Masks Definitions */
#define GE_EY_STATION_ADDRESS2_STATION_ADDRESS_6TH_OCTET (0x00ff0000)
#define GE_EY_STATION_ADDRESS2_STATION_ADDRESS_5TH_OCTET (0xff000000)
#define GE_EY_STATION_ADDRESS2_RESERVED			(0x0000ffff)

/* GE_EY_TR64 : Register Bits Masks Definitions */
#define GE_EY_TR64_TR64					(0x0003ffff)
#define GE_EY_TR64_RESERVED				(0xfffc0000)

/* GE_EY_TR127 : Register Bits Masks Definitions */
#define GE_EY_TR127_TR127				(0x0003ffff)
#define GE_EY_TR127_RESERVED				(0xfffc0000)

/* GE_EY_TR255 : Register Bits Masks Definitions */
#define GE_EY_TR255_TR255				(0x0003ffff)
#define GE_EY_TR255_RESERVED				(0xfffc0000)

/* GE_EY_TR511 : Register Bits Masks Definitions */
#define GE_EY_TR511_TR511				(0x0003ffff)
#define GE_EY_TR511_RESERVED				(0xfffc0000)

/* GE_EY_TR1K : Register Bits Masks Definitions */
#define GE_EY_TR1K_TR1K					(0x0003ffff)
#define GE_EY_TR1K_RESERVED				(0xfffc0000)

/* GE_EY_TRMAX : Register Bits Masks Definitions */
#define GE_EY_TRMAX_TRMAX				(0x0003ffff)
#define GE_EY_TRMAX_RESERVED				(0xfffc0000)

/* GE_EY_TRMGV : Register Bits Masks Definitions */
#define GE_EY_TRMGV_TRMGV				(0x0003ffff)
#define GE_EY_TRMGV_RESERVED				(0xfffc0000)

/* GE_EY_RBYT : Register Bits Masks Definitions */
#define GE_EY_RBYT_RBYT					(0x00ffffff)
#define GE_EY_RBYT_RESERVED				(0xff000000)

/* GE_EY_RPKT : Register Bits Masks Definitions */
#define GE_EY_RPKT_RPKT					(0x0003ffff)
#define GE_EY_RPKT_RESERVED				(0xfffc0000)

/* GE_EY_RFCS : Register Bits Masks Definitions */
#define GE_EY_RFCS_RFCS					(0x00000fff)
#define GE_EY_RFCS_RESERVED				(0xfffff000)

/* GE_EY_RMCA : Register Bits Masks Definitions */
#define GE_EY_RMCA_RMCA					(0x0003ffff)
#define GE_EY_RMCA_RESERVED				(0xfffc0000)

/* GE_EY_RBCA : Register Bits Masks Definitions */
#define GE_EY_RBCA_RBCA					(0x0003ffff)
#define GE_EY_RBCA_RESERVED				(0xfffc0000)

/* GE_EY_RXCF : Register Bits Masks Definitions */
#define GE_EY_RXCF_RXPF					(0x00000fff)
#define GE_EY_RXCF_RESERVED				(0xfffff000)

/* GE_EY_RXPF : Register Bits Masks Definitions */
#define GE_EY_RXPF_RXPF					(0x00000fff)
#define GE_EY_RXPF_RESERVED				(0xfffff000)

/* GE_EY_RXUO : Register Bits Masks Definitions */
#define GE_EY_RXUO_RXUO					(0x00000fff)
#define GE_EY_RXUO_RESERVED				(0xfffff000)

/* GE_EY_RALN : Register Bits Masks Definitions */
#define GE_EY_RALN_RALN					(0x00000fff)
#define GE_EY_RALN_RESERVED				(0xfffff000)

/* GE_EY_RFLR : Register Bits Masks Definitions */
#define GE_EY_RFLR_RXPF					(0x00000fff)
#define GE_EY_RFLR_RESERVED				(0xfffff000)

/* GE_EY_RCDE : Register Bits Masks Definitions */
#define GE_EY_RCDE_RCDE					(0x00000fff)
#define GE_EY_RCDE_RESERVED				(0xfffff000)

/* GE_EY_RCSE : Register Bits Masks Definitions */
#define GE_EY_RCSE_RCSE					(0x00000fff)
#define GE_EY_RCSE_RESERVED				(0xfffff000)

/* GE_EY_RUND : Register Bits Masks Definitions */
#define GE_EY_RUND_RUND					(0x00000fff)
#define GE_EY_RUND_RESERVED				(0xfffff000)

/* GE_EY_ROVR : Register Bits Masks Definitions */
#define GE_EY_ROVR_ROVR					(0x00000fff)
#define GE_EY_ROVR_RESERVED				(0xfffff000)

/* GE_EY_RFRG : Register Bits Masks Definitions */
#define GE_EY_RFRG_RFRG					(0x00000fff)
#define GE_EY_RFRG_RESERVED				(0xfffff000)

/* GE_EY_RJBR : Register Bits Masks Definitions */
#define GE_EY_RJBR_RJBR					(0x00000fff)
#define GE_EY_RJBR_RESERVED				(0xfffff000)

/* GE_EY_RDRP : Register Bits Masks Definitions */
#define GE_EY_RDRP_RDRP					(0x00000fff)
#define GE_EY_RDRP_RESERVED				(0xfffff000)

/* GE_EY_TBYT : Register Bits Masks Definitions */
#define GE_EY_TBYT_TBYT					(0x00ffffff)
#define GE_EY_TBYT_RESERVED				(0xff000000)

/* GE_EY_TPKT : Register Bits Masks Definitions */
#define GE_EY_TPKT_TPKT					(0x0003ffff)
#define GE_EY_TPKT_RESERVED				(0xfffc0000)

/* GE_EY_TMCA : Register Bits Masks Definitions */
#define GE_EY_TMCA_TMCA					(0x0003ffff)
#define GE_EY_TMCA_RESERVED				(0xfffc0000)

/* GE_EY_TBCA : Register Bits Masks Definitions */
#define GE_EY_TBCA_TBCA					(0x0003ffff)
#define GE_EY_TBCA_RESERVED				(0xfffc0000)

/* GE_EY_TXPF : Register Bits Masks Definitions */
#define GE_EY_TXPF_TXPF					(0x00000fff)
#define GE_EY_TXPF_RESERVED				(0xfffff000)

/* GE_EY_TDFR : Register Bits Masks Definitions */
#define GE_EY_TDFR_TDFR					(0x00000fff)
#define GE_EY_TDFR_RESERVED				(0xfffff000)

/* GE_EY_TEDF : Register Bits Masks Definitions */
#define GE_EY_TEDF_TEDF					(0x00000fff)
#define GE_EY_TEDF_RESERVED				(0xfffff000)

/* GE_EY_TSCL : Register Bits Masks Definitions */
#define GE_EY_TSCL_TSCL					(0x00000fff)
#define GE_EY_TSCL_RESERVED				(0xfffff000)

/* GE_EY_TMCL : Register Bits Masks Definitions */
#define GE_EY_TMCL_TMCL					(0x00000fff)
#define GE_EY_TMCL_RESERVED				(0xfffff000)

/* GE_EY_TLCL : Register Bits Masks Definitions */
#define GE_EY_TLCL_TLCL					(0x00000fff)
#define GE_EY_TLCL_RESERVED				(0xfffff000)

/* GE_EY_TXCL : Register Bits Masks Definitions */
#define GE_EY_TXCL_TXCL					(0x00000fff)
#define GE_EY_TXCL_RESERVED				(0xfffff000)

/* GE_EY_TNCL : Register Bits Masks Definitions */
#define GE_EY_TNCL_TNCL					(0x00000fff)
#define GE_EY_TNCL_RESERVED				(0xfffff000)

/* GE_EY_TPFH : Register Bits Masks Definitions */
#define GE_EY_TPFH_TPFH					(0x00000fff)
#define GE_EY_TPFH_RESERVED				(0xfffff000)

/* GE_EY_TDRP : Register Bits Masks Definitions */
#define GE_EY_TDRP_TDRP					(0x00000fff)
#define GE_EY_TDRP_RESERVED				(0xfffff000)

/* GE_EY_TJBR : Register Bits Masks Definitions */
#define GE_EY_TJBR_TJBR					(0x00000fff)
#define GE_EY_TJBR_RESERVED				(0xfffff000)

/* GE_EY_TFCS : Register Bits Masks Definitions */
#define GE_EY_TFCS_TFCS					(0x00000fff)
#define GE_EY_TFCS_RESERVED				(0xfffff000)

/* GE_EY_TXCF : Register Bits Masks Definitions */
#define GE_EY_TXCF_TXCF					(0x00000fff)
#define GE_EY_TXCF_RESERVED				(0xfffff000)

/* GE_EY_TOVR : Register Bits Masks Definitions */
#define GE_EY_TOVR_TOVR					(0x00000fff)
#define GE_EY_TOVR_RESERVED				(0xfffff000)

/* GE_EY_TUND : Register Bits Masks Definitions */
#define GE_EY_TUND_TUND					(0x00000fff)
#define GE_EY_TUND_RESERVED				(0xfffff000)

/* GE_EY_TFRG : Register Bits Masks Definitions */
#define GE_EY_TFRG_TFRG					(0x00000fff)
#define GE_EY_TFRG_RESERVED				(0xfffff000)

/* GE_EY_CAR1 : Register Bits Masks Definitions */
#define GE_EY_CAR1_C1_RDR				(0x00000001)
#define GE_EY_CAR1_C1_RJB				(0x00000002)
#define GE_EY_CAR1_C1_RFR				(0x00000004)
#define GE_EY_CAR1_C1_ROV				(0x00000008)
#define GE_EY_CAR1_C1_RUN				(0x00000010)
#define GE_EY_CAR1_C1_RCS				(0x00000020)
#define GE_EY_CAR1_C1_RCD				(0x00000040)
#define GE_EY_CAR1_C1_RFL				(0x00000080)
#define GE_EY_CAR1_C1_RAL				(0x00000100)
#define GE_EY_CAR1_C1_RXU				(0x00000200)
#define GE_EY_CAR1_C1_RXP				(0x00000400)
#define GE_EY_CAR1_C1_RXC				(0x00000800)
#define GE_EY_CAR1_C1_RBC				(0x00001000)
#define GE_EY_CAR1_C1_RMC				(0x00002000)
#define GE_EY_CAR1_C1_RFC				(0x00004000)
#define GE_EY_CAR1_C1_RPK				(0x00008000)
#define GE_EY_CAR1_C1_RBY				(0x00010000)
#define GE_EY_CAR1_C1_MGV				(0x02000000)
#define GE_EY_CAR1_C1_MAX				(0x04000000)
#define GE_EY_CAR1_C1_1K				(0x08000000)
#define GE_EY_CAR1_C1_511				(0x10000000)
#define GE_EY_CAR1_C1_255				(0x20000000)
#define GE_EY_CAR1_C1_127				(0x40000000)
#define GE_EY_CAR1_C1_64				(0x80000000)
#define GE_EY_CAR1_RESERVED				(0x01fe0000)

/* GE_EY_CAR2 : Register Bits Masks Definitions */
#define GE_EY_CAR2_C2_TDP				(0x00000001)
#define GE_EY_CAR2_C2_TPH				(0x00000002)
#define GE_EY_CAR2_C2_TNC				(0x00000004)
#define GE_EY_CAR2_C2_TXC				(0x00000008)
#define GE_EY_CAR2_C2_TLC				(0x00000010)
#define GE_EY_CAR2_C2_TMA				(0x00000020)
#define GE_EY_CAR2_C2_TSC				(0x00000040)
#define GE_EY_CAR2_C2_TED				(0x00000080)
#define GE_EY_CAR2_C2_TDF				(0x00000100)
#define GE_EY_CAR2_C2_TPF				(0x00000200)
#define GE_EY_CAR2_C2_TBC				(0x00000400)
#define GE_EY_CAR2_C2_TMC				(0x00000800)
#define GE_EY_CAR2_C2_TPK				(0x00001000)
#define GE_EY_CAR2_C2_TBY				(0x00002000)
#define GE_EY_CAR2_C2_TFG				(0x00004000)
#define GE_EY_CAR2_C2_TUN				(0x00008000)
#define GE_EY_CAR2_C2_TOV				(0x00010000)
#define GE_EY_CAR2_C2_TCF				(0x00020000)
#define GE_EY_CAR2_C2_TFC				(0x00040000)
#define GE_EY_CAR2_C2_TJB				(0x00080000)
#define GE_EY_CAR2_RESERVED				(0xfff00000)

/* GE_EY_CAM1 : Register Bits Masks Definitions */
#define GE_EY_CAM1_M1_RDR				(0x00000001)
#define GE_EY_CAM1_M1_RJB				(0x00000002)
#define GE_EY_CAM1_M1_RFR				(0x00000004)
#define GE_EY_CAM1_M1_ROV				(0x00000008)
#define GE_EY_CAM1_M1_RUN				(0x00000010)
#define GE_EY_CAM1_M1_RCS				(0x00000020)
#define GE_EY_CAM1_M1_RCD				(0x00000040)
#define GE_EY_CAM1_M1_RFL				(0x00000080)
#define GE_EY_CAM1_M1_RAL				(0x00000100)
#define GE_EY_CAM1_M1_RXU				(0x00000200)
#define GE_EY_CAM1_M1_RXP				(0x00000400)
#define GE_EY_CAM1_M1_RXC				(0x00000800)
#define GE_EY_CAM1_M1_RBC				(0x00001000)
#define GE_EY_CAM1_M1_RMC				(0x00002000)
#define GE_EY_CAM1_M1_RFC				(0x00004000)
#define GE_EY_CAM1_M1_RPK				(0x00008000)
#define GE_EY_CAM1_M1_RBY				(0x00010000)
#define GE_EY_CAM1_M1_MGV				(0x02000000)
#define GE_EY_CAM1_M1_MAX				(0x04000000)
#define GE_EY_CAM1_M1_1K				(0x08000000)
#define GE_EY_CAM1_M1_511				(0x10000000)
#define GE_EY_CAM1_M1_255				(0x20000000)
#define GE_EY_CAM1_M1_127				(0x40000000)
#define GE_EY_CAM1_M1_64				(0x80000000)
#define GE_EY_CAM1_RESERVED				(0x01fe0000)

/* GE_EY_CAM2 : Register Bits Masks Definitions */
#define GE_EY_CAM2_M2_TDP				(0x00000001)
#define GE_EY_CAM2_M2_TPH				(0x00000002)
#define GE_EY_CAM2_M2_TNC				(0x00000004)
#define GE_EY_CAM2_M2_TXC				(0x00000008)
#define GE_EY_CAM2_M2_TLC				(0x00000010)
#define GE_EY_CAM2_M2_TMA				(0x00000020)
#define GE_EY_CAM2_M2_TSC				(0x00000040)
#define GE_EY_CAM2_M2_TED				(0x00000080)
#define GE_EY_CAM2_M2_TDF				(0x00000100)
#define GE_EY_CAM2_M2_TPF				(0x00000200)
#define GE_EY_CAM2_M2_TBC				(0x00000400)
#define GE_EY_CAM2_M2_TMC				(0x00000800)
#define GE_EY_CAM2_M2_TPK				(0x00001000)
#define GE_EY_CAM2_M2_TBY				(0x00002000)
#define GE_EY_CAM2_M2_TFG				(0x00004000)
#define GE_EY_CAM2_M2_TUN				(0x00008000)
#define GE_EY_CAM2_M2_TOV				(0x00010000)
#define GE_EY_CAM2_M2_TCF				(0x00020000)
#define GE_EY_CAM2_M2_TFC				(0x00040000)
#define GE_EY_CAM2_M2_TJB				(0x00080000)
#define GE_EY_CAM2_RESERVED				(0xfff00000)

/* GE_EY_PORT_CONTROL : Register Bits Masks Definitions */
#define GE_EY_PORT_CONTROL_PRI				(0x00000001)
#define GE_EY_PORT_CONTROL_BPT				(0x00010000)
#define GE_EY_PORT_CONTROL_SPD				(0x00040000)
#define GE_EY_PORT_CONTROL_RBC				(0x00080000)
#define GE_EY_PORT_CONTROL_PRB				(0x00200000)
#define GE_EY_PORT_CONTROL_DIS				(0x00400000)
#define GE_EY_PORT_CONTROL_TBI				(0x00800000)
#define GE_EY_PORT_CONTROL_STE				(0x10000000)
#define GE_EY_PORT_CONTROL_ZOR				(0x20000000)
#define GE_EY_PORT_CONTROL_CLR				(0x40000000)
#define GE_EY_PORT_CONTROL_SRT				(0x80000000)
#define GE_EY_PORT_CONTROL_RESERVED			(0x0f12fffe)

/* GE_EY_PORT_INT_STATUS : Register Bits Masks Definitions */
#define GE_EY_PORT_INT_STATUS_TX_QUEUE			(0x0000000f)
#define GE_EY_PORT_INT_STATUS_TX_WAIT			(0x00000100)
#define GE_EY_PORT_INT_STATUS_TX_THR			(0x00000200)
#define GE_EY_PORT_INT_STATUS_TX_UNR			(0x00000400)
#define GE_EY_PORT_INT_STATUS_TX_ERR			(0x00000800)
#define GE_EY_PORT_INT_STATUS_TX_ABT			(0x00001000)
#define GE_EY_PORT_INT_STATUS_TX_IDLE			(0x00002000)
#define GE_EY_PORT_INT_STATUS_STC			(0x00008000)
#define GE_EY_PORT_INT_STATUS_RX_QUEUE			(0x000f0000)
#define GE_EY_PORT_INT_STATUS_RX_WAIT			(0x01000000)
#define GE_EY_PORT_INT_STATUS_RX_THR			(0x02000000)
#define GE_EY_PORT_INT_STATUS_RX_OVR			(0x04000000)
#define GE_EY_PORT_INT_STATUS_RX_ERR			(0x08000000)
#define GE_EY_PORT_INT_STATUS_RX_ABT			(0x10000000)
#define GE_EY_PORT_INT_STATUS_RX_IDLE			(0x20000000)
#define GE_EY_PORT_INT_STATUS_OCN_ERR			(0x40000000)
#define GE_EY_PORT_INT_STATUS_PORT_INTERRUPT		(0x80000000)
#define GE_EY_PORT_INT_STATUS_RESERVED			(0x00f040f0)

/* GE_EY_PORT_INT_MASK : Register Bits Masks Definitions */
#define GE_EY_PORT_INT_MASK_TX_QUEUE			(0x0000000f)
#define GE_EY_PORT_INT_MASK_TX_WAIT			(0x00000100)
#define GE_EY_PORT_INT_MASK_TX_THR			(0x00000200)
#define GE_EY_PORT_INT_MASK_TX_UNR			(0x00000400)
#define GE_EY_PORT_INT_MASK_TX_ERR			(0x00000800)
#define GE_EY_PORT_INT_MASK_TX_ABT			(0x00001000)
#define GE_EY_PORT_INT_MASK_TX_IDLE			(0x00002000)
#define GE_EY_PORT_INT_MASK_STC				(0x00008000)
#define GE_EY_PORT_INT_MASK_RX_QUEUE			(0x000f0000)
#define GE_EY_PORT_INT_MASK_RX_WAIT			(0x01000000)
#define GE_EY_PORT_INT_MASK_RX_THR			(0x02000000)
#define GE_EY_PORT_INT_MASK_RX_OVR			(0x04000000)
#define GE_EY_PORT_INT_MASK_RX_ERR			(0x08000000)
#define GE_EY_PORT_INT_MASK_RX_ABT			(0x10000000)
#define GE_EY_PORT_INT_MASK_RX_IDLE			(0x20000000)
#define GE_EY_PORT_INT_MASK_OCN_ERR			(0x40000000)
#define GE_EY_PORT_INT_MASK_RESERVED			(0x80f040f0)

/* GE_EY_OCN_STATUS : Register Bits Masks Definitions */
#define GE_EY_OCN_STATUS_OCN_RESPONSE_HEADER		(0x00ffffff)
#define GE_EY_OCN_STATUS_OCN_ERROR_COUNT		(0xff000000)

/* GE_EY_TX_CONFIGURATION : Register Bits Masks Definitions */
#define GE_EY_TX_CONFIGURATION_START_Q			(0x00000003)
#define GE_EY_TX_CONFIGURATION_EHP			(0x00400000)
#define GE_EY_TX_CONFIGURATION_CHP			(0x00800000)
#define GE_EY_TX_CONFIGURATION_RST			(0x80000000)
#define GE_EY_TX_CONFIGURATION_RESERVED			(0x7f3ffffc)

/* GE_EY_TX_CONTROL : Register Bits Masks Definitions */
#define GE_EY_TX_CONTROL_QUEUE_ENABLES			(0x0000000f)
#define GE_EY_TX_CONTROL_GO				(0x00008000)
#define GE_EY_TX_CONTROL_MP				(0x01000000)
#define GE_EY_TX_CONTROL_EAI				(0x20000000)
#define GE_EY_TX_CONTROL_ABT				(0x40000000)
#define GE_EY_TX_CONTROL_EII				(0x80000000)
#define GE_EY_TX_CONTROL_RESERVED			(0x1eff7ff0)

/* GE_EY_TX_STATUS : Register Bits Masks Definitions */
#define GE_EY_TX_STATUS_QUEUE_USABLE			(0x0000000f)
#define GE_EY_TX_STATUS_CURR_Q				(0x00000300)
#define GE_EY_TX_STATUS_ACT				(0x00008000)
#define GE_EY_TX_STATUS_QUEUE_IDLE			(0x000f0000)
#define GE_EY_TX_STATUS_EOQ_PENDING			(0x0f000000)
#define GE_EY_TX_STATUS_RESERVED			(0xf0f07cf0)

/* GE_EY_TX_EXTENDED_STATUS : Register Bits Masks Definitions */
#define GE_EY_TX_EXTENDED_STATUS_END_OF_QUEUE_CONDITION	(0x0000000f)
#define GE_EY_TX_EXTENDED_STATUS_END_OF_FRAME_CONDITION	(0x00000f00)
#define GE_EY_TX_EXTENDED_STATUS_DESCRIPTOR_INTERRUPT_CONDITION (0x000f0000)
#define GE_EY_TX_EXTENDED_STATUS_ERROR_FLAG		(0x0f000000)
#define GE_EY_TX_EXTENDED_STATUS_RESERVED		(0xf0f0f0f0)

/* GE_EY_TX_THRESHOLDS : Register Bits Masks Definitions */
#define GE_EY_TX_THRESHOLDS_START_SENDING_THRESHOLD	(0x000000ff)
#define GE_EY_TX_THRESHOLDS_STOP_FILLING_THRESHOLD	(0x00ff0000)
#define GE_EY_TX_THRESHOLDS_RESERVED			(0xff00ff00)

/* GE_EY_TX_PRIORITY_THRESHOLDS : Register Bits Masks Definitions */
#define GE_EY_TX_PRIORITY_THRESHOLDS_UNDERRUN_PRIORITY_THRESHOLD (0x000000ff)
#define GE_EY_TX_PRIORITY_THRESHOLDS_RESERVED		(0xffffff00)

/* GE_EY_TX_QUEUE_PRIORITY_MAP : Register Bits Masks Definitions */
#define GE_EY_TX_QUEUE_PRIORITY_MAP_NEXT_QUEUE_AFTER_0	(0x00000003)
#define GE_EY_TX_QUEUE_PRIORITY_MAP_REVERT_AFTER_0	(0x00000008)
#define GE_EY_TX_QUEUE_PRIORITY_MAP_FRAME_LIMIT_QUEUE_0	(0x000000f0)
#define GE_EY_TX_QUEUE_PRIORITY_MAP_NEXT_QUEUE_AFTER_1	(0x00000300)
#define GE_EY_TX_QUEUE_PRIORITY_MAP_REVERT_AFTER_1	(0x00000800)
#define GE_EY_TX_QUEUE_PRIORITY_MAP_FRAME_LIMIT_QUEUE_1	(0x0000f000)
#define GE_EY_TX_QUEUE_PRIORITY_MAP_NEXT_QUEUE_AFTER_2	(0x00030000)
#define GE_EY_TX_QUEUE_PRIORITY_MAP_REVERT_AFTER_2	(0x00080000)
#define GE_EY_TX_QUEUE_PRIORITY_MAP_FRAME_LIMIT_QUEUE_2	(0x00f00000)
#define GE_EY_TX_QUEUE_PRIORITY_MAP_NEXT_QUEUE_AFTER_3	(0x03000000)
#define GE_EY_TX_QUEUE_PRIORITY_MAP_REVERT_AFTER_3	(0x08000000)
#define GE_EY_TX_QUEUE_PRIORITY_MAP_FRAME_LIMIT_QUEUE_3	(0xf0000000)
#define GE_EY_TX_QUEUE_PRIORITY_MAP_RESERVED		(0x04040404)

/* GE_EY_TX_PENDING_COMPLETION : Register Bits Masks Definitions */
#define GE_EY_TX_PENDING_COMPLETION_PENDING_QUEUE_0	(0x0000003f)
#define GE_EY_TX_PENDING_COMPLETION_PENDING_QUEUE_1	(0x00003f00)
#define GE_EY_TX_PENDING_COMPLETION_PENDING_QUEUE_2	(0x003f0000)
#define GE_EY_TX_PENDING_COMPLETION_PENDING_QUEUE_3	(0x3f000000)
#define GE_EY_TX_PENDING_COMPLETION_RESERVED		(0xc0c0c0c0)

/* GE_EY_TX_PAUSE_COUNT : Register Bits Masks Definitions */
#define GE_EY_TX_PAUSE_COUNT_PAUSE_COUNT		(0x0000ffff)
#define GE_EY_TX_PAUSE_COUNT_RESERVED			(0xffff0000)

/* GE_EY_TX_GLOBAL_VLAN_TAG : Register Bits Masks Definitions */
#define GE_EY_TX_GLOBAL_VLAN_TAG_GLOBAL_VLAN_TAG	(0xffffffff)

/* GE_EY_TX_DIAGNOSTIC_INDIRECT_ADDRESS : Register Bits Masks Definitions */
#define GE_EY_TX_DIAGNOSTIC_INDIRECT_ADDRESS_INDEX	(0x0000007f)
#define GE_EY_TX_DIAGNOSTIC_INDIRECT_ADDRESS_DFR	(0x40000000)
#define GE_EY_TX_DIAGNOSTIC_INDIRECT_ADDRESS_AI		(0x80000000)
#define GE_EY_TX_DIAGNOSTIC_INDIRECT_ADDRESS_RESERVED	(0x3fffff80)

/* GE_EY_TX_DIAGNOSTIC_INDIRECT_DATA : Register Bits Masks Definitions */
#define GE_EY_TX_DIAGNOSTIC_INDIRECT_DATA_DIAGNOSTIC_DATA (0xffffffff)

/* GE_EY_TX_ERROR_STATUS : Register Bits Masks Definitions */
#define GE_EY_TX_ERROR_STATUS_QUEUE_0_ERROR_RESPONSE	(0x0000000f)
#define GE_EY_TX_ERROR_STATUS_TEA_ON_QUEUE_0		(0x00000010)
#define GE_EY_TX_ERROR_STATUS_RER_ON_QUEUE_0		(0x00000020)
#define GE_EY_TX_ERROR_STATUS_TER_ON_QUEUE_0		(0x00000040)
#define GE_EY_TX_ERROR_STATUS_DER_ON_QUEUE_0		(0x00000080)
#define GE_EY_TX_ERROR_STATUS_QUEUE_1_ERROR_RESPONSE	(0x00000f00)
#define GE_EY_TX_ERROR_STATUS_TEA_ON_QUEUE_1		(0x00001000)
#define GE_EY_TX_ERROR_STATUS_RER_ON_QUEUE_1		(0x00002000)
#define GE_EY_TX_ERROR_STATUS_TER_ON_QUEUE_1		(0x00004000)
#define GE_EY_TX_ERROR_STATUS_DER_ON_QUEUE_1		(0x00008000)
#define GE_EY_TX_ERROR_STATUS_QUEUE_2_ERROR_RESPONSE	(0x000f0000)
#define GE_EY_TX_ERROR_STATUS_TEA_ON_QUEUE_2		(0x00100000)
#define GE_EY_TX_ERROR_STATUS_RER_ON_QUEUE_2		(0x00200000)
#define GE_EY_TX_ERROR_STATUS_TER_ON_QUEUE_2		(0x00400000)
#define GE_EY_TX_ERROR_STATUS_DER_ON_QUEUE_2		(0x00800000)
#define GE_EY_TX_ERROR_STATUS_QUEUE_3_ERROR_RESPONSE	(0x0f000000)
#define GE_EY_TX_ERROR_STATUS_TEA_ON_QUEUE_3		(0x10000000)
#define GE_EY_TX_ERROR_STATUS_RER_ON_QUEUE_3		(0x20000000)
#define GE_EY_TX_ERROR_STATUS_TER_ON_QUEUE_3		(0x40000000)
#define GE_EY_TX_ERROR_STATUS_DER_ON_QUEUE_3		(0x80000000)

/* GE_EY_TX_QUEUE_N_CONFIGURATION : Register Bits Masks Definitions */
#define GE_EY_TX_QUEUE_N_CONFIGURATION_OCN_PORT		(0x0000003f)
#define GE_EY_TX_QUEUE_N_CONFIGURATION_BSWP		(0x00000400)
#define GE_EY_TX_QUEUE_N_CONFIGURATION_WSWP		(0x00000800)
#define GE_EY_TX_QUEUE_N_CONFIGURATION_AM		(0x00004000)
#define GE_EY_TX_QUEUE_N_CONFIGURATION_GVI		(0x00008000)
#define GE_EY_TX_QUEUE_N_CONFIGURATION_EEI		(0x00010000)
#define GE_EY_TX_QUEUE_N_CONFIGURATION_ELI		(0x00020000)
#define GE_EY_TX_QUEUE_N_CONFIGURATION_ENI		(0x00040000)
#define GE_EY_TX_QUEUE_N_CONFIGURATION_ESI		(0x00080000)
#define GE_EY_TX_QUEUE_N_CONFIGURATION_EDI		(0x00100000)
#define GE_EY_TX_QUEUE_N_CONFIGURATION_RESERVED		(0xffe033c0)

/* GE_EY_TX_QUEUE_N_BUFFER_CONFIG : Register Bits Masks Definitions */
#define GE_EY_TX_QUEUE_N_BUFFER_CONFIG_OCN_PORT		(0x0000003f)
#define GE_EY_TX_QUEUE_N_BUFFER_CONFIG_BURST		(0x00000300)
#define GE_EY_TX_QUEUE_N_BUFFER_CONFIG_BSWP		(0x00000400)
#define GE_EY_TX_QUEUE_N_BUFFER_CONFIG_WSWP		(0x00000800)
#define GE_EY_TX_QUEUE_N_BUFFER_CONFIG_RESERVED		(0xfffff0c0)

/* GE_EY_TX_QUEUE_N_PTR_LOW : Register Bits Masks Definitions */
#define GE_EY_TX_QUEUE_N_PTR_LOW_DESCRIPTOR_ADDRESS	(0xffffffff)

/* GE_EY_TX_QUEUE_0_PTR_HIGH : Register Bits Masks Definitions */
#define GE_EY_TX_QUEUE_N_PTR_HIGH_DESCRIPTOR_ADDRESS	(0x00000fff)
#define GE_EY_TX_QUEUE_N_PTR_HIGH_VALID			(0x80000000)
#define GE_EY_TX_QUEUE_N_PTR_HIGH_RESERVED		(0x7ffff000)

/* GE_EY_RX_CONFIGURATION : Register Bits Masks Definitions */
#define GE_EY_RX_CONFIGURATION_DEF_Q			(0x00000003)
#define GE_EY_RX_CONFIGURATION_EMF			(0x00000100)
#define GE_EY_RX_CONFIGURATION_EUF			(0x00000200)
#define GE_EY_RX_CONFIGURATION_BFE			(0x00000400)
#define GE_EY_RX_CONFIGURATION_MFE			(0x00000800)
#define GE_EY_RX_CONFIGURATION_UFE			(0x00001000)
#define GE_EY_RX_CONFIGURATION_SE			(0x00002000)
#define GE_EY_RX_CONFIGURATION_ABF			(0x00200000)
#define GE_EY_RX_CONFIGURATION_APE			(0x00400000)
#define GE_EY_RX_CONFIGURATION_CHP			(0x00800000)
#define GE_EY_RX_CONFIGURATION_RST			(0x80000000)
#define GE_EY_RX_CONFIGURATION_RESERVED			(0x7f1fc0fc)

/* GE_EY_RX_CONTROL : Register Bits Masks Definitions */
#define GE_EY_RX_CONTROL_QUEUE_ENABLES			(0x0000000f)
#define GE_EY_RX_CONTROL_GO				(0x00008000)
#define GE_EY_RX_CONTROL_EAI				(0x20000000)
#define GE_EY_RX_CONTROL_ABT				(0x40000000)
#define GE_EY_RX_CONTROL_EII				(0x80000000)
#define GE_EY_RX_CONTROL_RESERVED			(0x1fff7ff0)

/* GE_EY_RX_STATUS : Register Bits Masks Definitions */
#define GE_EY_RX_STATUS_QUEUE_USABLE			(0x0000000f)
#define GE_EY_RX_STATUS_CUR_Q				(0x00000300)
#define GE_EY_RX_STATUS_PRB				(0x00004000)
#define GE_EY_RX_STATUS_ACT				(0x00008000)
#define GE_EY_RX_STATUS_QUEUE_IDLE			(0x000f0000)
#define GE_EY_RX_STATUS_RESERVED			(0xfff03cf0)

/* GE_EY_RX_EXTENDED_STATUS : Register Bits Masks Definitions */
#define GE_EY_RX_EXTENDED_STATUS_EOQ			(0x0000000f)
#define GE_EY_RX_EXTENDED_STATUS_EOF			(0x00000f00)
#define GE_EY_RX_EXTENDED_STATUS_DESCRIPTOR_INTERRUPT_CONDITION (0x000f0000)
#define GE_EY_RX_EXTENDED_STATUS_ERROR_FLAG		(0x0f000000)
#define GE_EY_RX_EXTENDED_STATUS_RESERVED		(0xf0f0f0f0)

/* GE_EY_RX_PAUSE_THRESHOLDS : Register Bits Masks Definitions */
#define GE_EY_RX_PAUSE_THRESHOLDS_UNPAUSE_THRESHOLD	(0x000001ff)
#define GE_EY_RX_PAUSE_THRESHOLDS_PAUSE_THRESHOLD	(0x01ff0000)
#define GE_EY_RX_PAUSE_THRESHOLDS_RESERVED		(0xfe00fe00)

/* GE_EY_RX_THRESHOLD : Register Bits Masks Definitions */
#define GE_EY_RX_THRESHOLD_OVERRUN_WARNING_THRESHOLD	(0x000001ff)
#define GE_EY_RX_THRESHOLD_RESERVED			(0xfffffe00)

/* GE_EY_RX_VLAN_TAG_MAP : Register Bits Masks Definitions */
#define GE_EY_RX_VLAN_TAG_MAP_QUEUE_FOR_TAG_0		(0x00000003)
#define GE_EY_RX_VLAN_TAG_MAP_QUEUE_FOR_TAG_1		(0x00000030)
#define GE_EY_RX_VLAN_TAG_MAP_QUEUE_FOR_TAG_2		(0x00000300)
#define GE_EY_RX_VLAN_TAG_MAP_QUEUE_FOR_TAG_3		(0x00003000)
#define GE_EY_RX_VLAN_TAG_MAP_QUEUE_FOR_TAG_4		(0x00030000)
#define GE_EY_RX_VLAN_TAG_MAP_QUEUE_FOR_TAG_5		(0x00300000)
#define GE_EY_RX_VLAN_TAG_MAP_QUEUE_FOR_TAG_6		(0x03000000)
#define GE_EY_RX_VLAN_TAG_MAP_QUEUE_FOR_TAG_7		(0x30000000)
#define GE_EY_RX_VLAN_TAG_MAP_RESERVED			(0xcccccccc)

/* GE_EY_RX_HASH_TABLE_INDIRECT_ADDRESS : Register Bits Masks Definitions */
#define GE_EY_RX_HASH_TABLE_INDIRECT_ADDRESS_INDEX	(0x0000000f)
#define GE_EY_RX_HASH_TABLE_INDIRECT_ADDRESS_MCAD	(0x00000010)
#define GE_EY_RX_HASH_TABLE_INDIRECT_ADDRESS_DFR	(0x40000000)
#define GE_EY_RX_HASH_TABLE_INDIRECT_ADDRESS_AI		(0x80000000)
#define GE_EY_RX_HASH_TABLE_INDIRECT_ADDRESS_RESERVED	(0x3fffffe0)

/* GE_EY_RX_HASH_TABLE_INDIRECT_DATA : Register Bits Masks Definitions */
#define GE_EY_RX_HASH_TABLE_INDIRECT_DATA_HASH_TABLE_DATA (0xffffffff)

/* GE_EY_RX_DIAGNOSTIC_INDIRECT_ADDRESS : Register Bits Masks Definitions */
#define GE_EY_RX_DIAGNOSTIC_INDIRECT_ADDRESS_INDEX	(0x0000001f)
#define GE_EY_RX_DIAGNOSTIC_INDIRECT_ADDRESS_DFR	(0x40000000)
#define GE_EY_RX_DIAGNOSTIC_INDIRECT_ADDRESS_AI		(0x80000000)
#define GE_EY_RX_DIAGNOSTIC_INDIRECT_ADDRESS_RESERVED	(0x3fffffe0)

/* GE_EY_RX_DIAGNOSTIC_INDIRECT_DATA : Register Bits Masks Definitions */
#define GE_EY_RX_DIAGNOSTIC_INDIRECT_DATA_DIAGNOSTIC_DATA (0xffffffff)

/* GE_EY_RX_ERROR_STATUS : Register Bits Masks Definitions */
#define GE_EY_RX_ERROR_STATUS_QUEUE_0_ERROR_RESPONSE	(0x0000000f)
#define GE_EY_RX_ERROR_STATUS_TEA_ON_QUEUE_0		(0x00000010)
#define GE_EY_RX_ERROR_STATUS_RER_ON_QUEUE_0		(0x00000020)
#define GE_EY_RX_ERROR_STATUS_TER_ON_QUEUE_0		(0x00000040)
#define GE_EY_RX_ERROR_STATUS_DER_ON_QUEUE_0		(0x00000080)
#define GE_EY_RX_ERROR_STATUS_QUEUE_1_ERROR_RESPONSE	(0x00000f00)
#define GE_EY_RX_ERROR_STATUS_TEA_ON_QUEUE_1		(0x00001000)
#define GE_EY_RX_ERROR_STATUS_RER_ON_QUEUE_1		(0x00002000)
#define GE_EY_RX_ERROR_STATUS_TER_ON_QUEUE_1		(0x00004000)
#define GE_EY_RX_ERROR_STATUS_DER_ON_QUEUE_1		(0x00008000)
#define GE_EY_RX_ERROR_STATUS_QUEUE_2_ERROR_RESPONSE	(0x000f0000)
#define GE_EY_RX_ERROR_STATUS_TEA_ON_QUEUE_2		(0x00100000)
#define GE_EY_RX_ERROR_STATUS_RER_ON_QUEUE_2		(0x00200000)
#define GE_EY_RX_ERROR_STATUS_TER_ON_QUEUE_2		(0x00400000)
#define GE_EY_RX_ERROR_STATUS_DER_ON_QUEUE_2		(0x00800000)
#define GE_EY_RX_ERROR_STATUS_QUEUE_3_ERROR_RESPONSE	(0x0f000000)
#define GE_EY_RX_ERROR_STATUS_TEA_ON_QUEUE_3		(0x10000000)
#define GE_EY_RX_ERROR_STATUS_RER_ON_QUEUE_3		(0x20000000)
#define GE_EY_RX_ERROR_STATUS_TER_ON_QUEUE_3		(0x40000000)
#define GE_EY_RX_ERROR_STATUS_DER_ON_QUEUE_3		(0x80000000)

/* GE_EY_RX_QUEUE_N_CONFIGURATION : Register Bits Masks Definitions */
#define GE_EY_RX_QUEUE_N_CONFIGURATION_OCN_PORT		(0x0000003f)
#define GE_EY_RX_QUEUE_N_CONFIGURATION_BSWP		(0x00000400)
#define GE_EY_RX_QUEUE_N_CONFIGURATION_WSWP		(0x00000800)
#define GE_EY_RX_QUEUE_N_CONFIGURATION_AM		(0x00004000)
#define GE_EY_RX_QUEUE_N_CONFIGURATION_EEI		(0x00010000)
#define GE_EY_RX_QUEUE_N_CONFIGURATION_ELI		(0x00020000)
#define GE_EY_RX_QUEUE_N_CONFIGURATION_ENI		(0x00040000)
#define GE_EY_RX_QUEUE_N_CONFIGURATION_ESI		(0x00080000)
#define GE_EY_RX_QUEUE_N_CONFIGURATION_EDI		(0x00100000)
#define GE_EY_RX_QUEUE_N_CONFIGURATION_RESERVED		(0xffe0b3c0)

/* GE_EY_RX_QUEUE_N_BUFFER_CONFIGURATION : Register Bits Masks Definitions */
#define GE_EY_RX_QUEUE_N_BUFFER_CONFIGURATION_OCN_PORT	(0x0000003f)
#define GE_EY_RX_QUEUE_N_BUFFER_CONFIGURATION_BURST	(0x00000300)
#define GE_EY_RX_QUEUE_N_BUFFER_CONFIGURATION_BSWP	(0x00000400)
#define GE_EY_RX_QUEUE_N_BUFFER_CONFIGURATION_WSWP	(0x00000800)
#define GE_EY_RX_QUEUE_N_BUFFER_CONFIGURATION_RESERVED	(0xfffff0c0)

/* GE_EY_RX_QUEUE_N_POINTER_LOW : Register Bits Masks Definitions */
#define GE_EY_RX_QUEUE_N_POINTER_LOW_DESCRIPTOR_ADDRESS	(0xffffffff)

/* GE_EY_RX_QUEUE_N_POINTER_HIGH : Register Bits Masks Definitions */
#define GE_EY_RX_QUEUE_N_POINTER_HIGH_DESCRIPTOR_ADDRESS (0x00000fff)
#define GE_EY_RX_QUEUE_N_POINTER_HIGH_VALID		(0x80000000)
#define GE_EY_RX_QUEUE_N_POINTER_HIGH_RESERVED		(0x7ffff000)

#endif /* _TS_GE_H_  */
