/*
 * (C) Copyright 2007 Tundra Semiconductor Corp.
 * http://www.tundra.com/Support/SupportForm.cfm
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

/*-----------------------------------------------------------------------------
* FILENAME: ts_hlp.h
*
* DESCRIPTION: Header file contains the TSI110 HLP port register definitions
*              and bitmasks
* HISTORY:
*
*    Rev. Date           Author          Description
*    ---- ------------   -------------   --------------------------------------
*         Apr 27, 2007   Jason McKenna   Improve formatting
*         Mar 14, 2007   Jason McKenna   Original release.
*----------------------------------------------------------------------------*/

#ifndef _TS_HLP_H_
#define _TS_HLP_H_

#define HLP_MAX_PORTS						4

/* *************************************************/
/* HLP : Register address offset definitions	   */
/* *************************************************/

#define HLP_BX_ADDR(x)						(0x0 + 0x10*x)
#define HLP_BX_MASK(x)						(0x4 + 0x10*x)
#define HLP_BX_CTRL0(x)						(0x8 + 0x10*x)
#define HLP_BX_CTRL1(x)						(0xC + 0x10*x)

#define HLP_DATA_SWAP_CTRL					(0x00000040)
#define HLP_ERR							(0x00000044)


/* *************************************************/
/* HLP : Register Bit Mask definitions             */
/* *************************************************/

/* HLP_BX_ADDR : Register Bit Masks Definitions */

#define HLP_BX_ADDR_A						(0xffffff00)
#define HLP_BX_ADDR_RESERVED					(0x000000ff)

/* HLP_BX_MASK : Register Bit Masks Definitions */

#define HLP_BX_MASK_M						(0xffffff00)
#define HLP_BX_MASK_RESERVED					(0x000000ff)

/* HLP_BX_CTRL0 : Register Bits Masks Definitions */
#define HLP_BX_CTRL0_WIDTH					(0x00000003)
#define HLP_BX_CTRL0_FWT					(0x000000fc)
#define HLP_BX_CTRL0_THWR					(0x00000f00)
#define HLP_BX_CTRL0_THRD					(0x0000f000)
#define HLP_BX_CTRL0_WEON					(0x000c0000)
#define HLP_BX_CTRL0_OEON					(0x00300000)
#define HLP_BX_CTRL0_CSON					(0x00c00000)
#define HLP_BX_CTRL0_WAIT					(0x3f000000)
#define HLP_BX_CTRL0_FWE					(0x40000000)
#define HLP_BX_CTRL0_BM						(0x80000000)
#define HLP_BX_CTRL0_RESERVD					(0x00030000)

/* HLP_BX_CTRL1 : Register Bits Masks Definitions */
#define HLP_BX_CTRL1_PAGE					(0x0000e000)
#define HLP_BX_CTRL1_WEOFF					(0x000f0000)
#define HLP_BX_CTRL1_ARE					(0x01000000)
#define HLP_BX_CTRL1_RE						(0x02000000)
#define HLP_BX_CTRL1_LEHD					(0x0c000000)
#define HLP_BX_CTRL1_LE						(0x30000000)
#define HLP_BX_CTRL1_ENABLE					(0x40000000)
#define HLP_BX_CTRL1_MODE					(0x80000000)
#define HLP_BX_CTRL1_RESERVED					(0x00f01fff)

/* HLP_DATA_SWAP_CTRL : Register Bits Masks Definitions */
#define HLP_DATA_SWAP_CTRL_DATA_SWAP				(0x00000003)
#define HLP_DATA_SWAP_CTRL_RESERVED				(0xfffffffc)

/* HLP_DATA_SWAP_CTRL : Swapping Configuration Values */
#define HLP_DATA_SWAP_CTRL_DATA_SWAP_NO				(0x00000000)
#define HLP_DATA_SWAP_CTRL_DATA_SWAP_B				(0x00000001)
#define HLP_DATA_SWAP_CTRL_DATA_SWAP_W				(0x00000002)
#define HLP_DATA_SWAP_CTRL_DATA_SWAP_BW				(0x00000003)

/* HLP_ERR : Register Bits Masks Definitions */
#define HLP_ERR_TEA						(0x00000001)
#define HLP_ERR_INT_EN						(0x00000002)
#define HLP_ERR_ERR_MSG						(0x0000ff00)
#define HLP_ERR_RESERVED					(0xffff00fc)

#endif /* _TS_HLP_H_  */
