/*
 * (C) Copyright 2007 Tundra Semiconductor Corp.
 * http://www.tundra.com/Support/SupportForm.cfm
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

/*-----------------------------------------------------------------------------
* FILENAME: ts_i2c.h
*
* DESCRIPTION: Header file contains the TSI110 I2C register definitions
*              and bitmasks
* HISTORY:
*
*    Rev. Date           Author          Description
*    ---- ------------   -------------   --------------------------------------
*         May 08, 2007   Jason McKenna   Improve formatting
*         Apr 27, 2007   Jason McKenna   Improve formatting
*         Mar 14, 2007   Jason McKenna   Original release.
*----------------------------------------------------------------------------*/

#ifndef _TS_I2C_H_
#define _TS_I2C_H_

/* **********************************************/
/* I2C : Register address offset definitions    */
/* **********************************************/
#define I2C_CNTRL1						(0x00000000)
#define I2C_CNTRL2						(0x00000004)
#define I2C_RD_DATA						(0x00000008)
#define I2C_TX_DATA						(0x0000000c)

/* **********************************************/
/* I2C : Register Bit Masks and Reset Values    */
/*           definitions for every register     */
/* **********************************************/

/* I2C_CNTRL1 : Register Bits Masks Definitions */
#define I2C_CNTRL1_DEVCODE					(0x0000000f)
#define I2C_CNTRL1_PAGE						(0x00000700)
#define I2C_CNTRL1_BYTADDR					(0x00ff0000)
#define I2C_CNTRL1_I2CWRITE					(0x01000000)
#define I2C_CNTRL1_RESERVED					(0xfe00f8f0)

/* I2C_CNTRL2 : Register Bits Masks Definitions */
#define I2C_CNTRL2_SIZE						(0x00000003)
#define I2C_CNTRL2_LANE						(0x0000000c)
#define I2C_CNTRL2_MULTIBYTE					(0x00000010)
#define I2C_CNTRL2_START					(0x00000100)
#define I2C_CNTRL2_WR_STATUS					(0x00010000)
#define I2C_CNTRL2_RD_STATUS					(0x00020000)
#define I2C_CNTRL2_I2C_TO_ERR					(0x04000000)
#define I2C_CNTRL2_I2C_CFGERR					(0x08000000)
#define I2C_CNTRL2_I2C_CMPLT					(0x10000000)
#define I2C_CNTRL2_RESERVED					(0xe3fcfee0)

/* I2C_RD_DATA : Register Bits Masks Definitions */
#define I2C_RD_DATA_RBYTE0					(0x000000ff)
#define I2C_RD_DATA_RBYTE1					(0x0000ff00)
#define I2C_RD_DATA_RBYTE2					(0x00ff0000)
#define I2C_RD_DATA_RBYTE3					(0xff000000)
#define I2C_RD_DATA_RESERVED					(0x00000000)

/* I2C_TX_DATA : Register Bits Masks Definitions */
#define I2C_TX_DATA_TBYTE0					(0x000000ff)
#define I2C_TX_DATA_TBYTE1					(0x0000ff00)
#define I2C_TX_DATA_TBYTE2					(0x00ff0000)
#define I2C_TX_DATA_TBYTE3					(0xff000000)
#define I2C_TX_DATA_RESERVED					(0x00000000)

#endif /* _TS_I2C_H_  */
