/*
 * (C) Copyright 2007 Tundra Semiconductor Corp.
 * http://www.tundra.com/Support/SupportForm.cfm
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

/*-----------------------------------------------------------------------------
* FILENAME: ts_mpic.h
*
* DESCRIPTION: Header file contains the TSI110 MPIC port register definitions
*              and bitmasks
*
* HISTORY:
*
*    Rev. Date           Author          Description
*    ---- ------------   -------------   --------------------------------------
*         Apr 27, 2007   Jason McKenna   Improve formatting
*         Mar 14, 2007   Jason McKenna   Original release.
*----------------------------------------------------------------------------*/

#ifndef _TS_MPIC_H_
#define _TS_MPIC_H_
/* ***********************************************/
/* MPIC : Register address offset definitions    */
/* ***********************************************/

/* Global interrupt registers */
#define MPIC_INT_FRR					(0x00000000)
#define MPIC_INT_GCR					(0x00000004)
#define MPIC_INT_ICR					(0x00000008)
#define MPIC_INT_MVI					(0x0000000c)
#define MPIC_INT_SVR					(0x00000010)
#define MPIC_INT_TFRR					(0x00000014)
#define MPIC_INT_SOFT_SET				(0x00000020)
#define MPIC_INT_SOFT_ENABLE				(0x00000024)

/* Timer registers */
#define MAX_MPIC_GT					4
#define MPIC_INT_GTCCRX(x)				(0x30+0x10*(x))
#define MPIC_INT_GTBCRX(x)				(0x34+0x10*(x))
#define MPIC_INT_GTVPRX(x)				(0x38+0x10*(x))
#define MPIC_INT_GTDR0X(x)				(0x3c+0x10*(x))

/* Interrupt controller input pins */
#define MAX_MPIC_INT_INPUTS				24
#define MPIC_INT_IVPRX(x)				(0x100 + 0x08*(x))
#define MPIC_INT_IDRX(x)				(0x104 + 0x08*(x))

/* Doorbell registers */
#define MPIC_INT_DAR					(0x00000200)

#define MAX_MPIC_DOORS					4
#define MPIC_INT_DVPRX(x)				(0x204 + 0xc*(x))
#define MPIC_INT_DDRX(x)				(0x208 + 0xc*(x))
#define MPIC_INT_DMRX(x)				(0x20c + 0xc*(x))

/* Mailbox registers */
#define MAX_MPX_MAILBOXES				4
#define MPIC_INT_MBRX(x)				(0x280 + 0x10*(x))
#define MPIC_INT_MBVPRX(x)				(0x284 + 0x10*(x))
#define MPIC_INT_MBDRX(x)				(0x288 + 0x10*(x))

/* Interrupt controller output pins */
#define MAX_MPIC_INT_OUTPUTS				4

#define MPIC_INT_TASKPX(x)				(0x300+ 0x40*(x))
#define MPIC_INT_VECTORX(x)				(0x304+ 0x40*(x))
#define MPIC_INT_EOIX(x)				(0x308+ 0x40*(x))
#define MPIC_INT_CSRX(x)				(0x30c+ 0x40*(x))

/* ***********************************************/
/* MPIC : Register Bit Masks and Reset Values    */
/*           definitions for every register      */
/* ***********************************************/

/* MPIC_INT_FRR : Register Bits Masks Definitions */
#define MPIC_INT_FRR_VID				(0x000000ff)
#define MPIC_INT_FRR_NCPU				(0x00001f00)
#define MPIC_INT_FRR_NITM				(0x0000e000)
#define MPIC_INT_FRR_NIRQ				(0x07ff0000)
#define MPIC_INT_FRR_NIDOOR				(0xe0000000)
#define MPIC_INT_FRR_RESERVED				(0x18000000)

/* MPIC_INT_GCR : Register Bits Masks Definitions */
#define MPIC_INT_GCR_R					(0x80000000)
#define MPIC_INT_GCR_RESERVED				(0x7fffffff)

/* MPIC_INT_ICR : Register Bits Masks Definitions */
#define MPIC_INT_ICR_R					(0x0000000f)
#define MPIC_INT_ICR_RESERVED				(0xfffffff0)

/* MPIC_INT_MVI : Register Bits Masks Definitions */
#define MPIC_INT_MVI_VID				(0x000000ff)
#define MPIC_INT_MVI_DID				(0x0000ff00)
#define MPIC_INT_MVI_STEP				(0x00ff0000)
#define MPIC_INT_MVI_RESERVED				(0xff000000)

/* MPIC_INT_SVR : Register Bits Masks Definitions */
#define MPIC_INT_SVR_VECTOR				(0x000000ff)
#define MPIC_INT_SVR_RESERVED				(0xffffff00)

/* MPIC_INT_TFRR : Register Bits Masks Definitions */
#define MPIC_INT_TFRR_TIME_FREQ				(0xffffffff)

/* MPIC_INT_SOFT_SET : Register Bits Masks Definitions */
#define MPIC_INT_SOFT_SET_S				(0x00ffffff)
#define MPIC_INT_SOFT_SET_RESERVED			(0xff000000)

/* MPIC_INT_SOFT_ENABLE : Register Bits Masks Definitions */
#define MPIC_INT_SOFT_ENABLE_EN				(0x00ffffff)
#define MPIC_INT_SOFT_ENABLE_RESERVED			(0xff000000)

/* MPIC_INT_GTCCRX : Register Bits Masks Definitions */
#define MPIC_INT_GTCCRX_COUNT				(0x7fffffff)
#define MPIC_INT_GTCCRX_T				(0x80000000)

/* MPIC_INT_GTBCRX : Register Bits Masks Definitions */
#define MPIC_INT_GTBCRX_B_COUNT				(0x7fffffff)
#define MPIC_INT_GTBCRX_CI				(0x80000000)

/* MPIC_INT_GTVPRX : Register Bits Masks Definitions */
#define MPIC_INT_GTVPRX_VECTOR				(0x000000ff)
#define MPIC_INT_GTVPRX_PRIORITY			(0x000f0000)
#define MPIC_INT_GTVPRX_PRESCALE			(0x00f00000)
#define MPIC_INT_GTVPRX_A				(0x40000000)
#define MPIC_INT_GTVPRX_M				(0x80000000)
#define MPIC_INT_GTVPRX_RESERVED			(0x3f00ff00)

/* MPIC_INT_GTDRX : Register Bits Masks Definitions */
#define MPIC_INT_GTDRX_SEL_OUT				(0x0000000f)
#define MPIC_INT_GTDRX_RESERVED				(0xfffffff0)

/* MPIC_INT_IVPRX : Register Bits Masks Definitions */
#define MPIC_INT_IVPRX_VECTOR				(0x000000ff)
#define MPIC_INT_IVPRX_PRIORITY				(0x000f0000)
#define MPIC_INT_IVPRX_P				(0x01000000)
#define MPIC_INT_IVPRX_S				(0x02000000)
#define MPIC_INT_IVPRX_MODE				(0x20000000)
#define MPIC_INT_IVPRX_A				(0x40000000)
#define MPIC_INT_IVPRX_M				(0x80000000)
#define MPIC_INT_IVPRX_RESERVED				(0x1cf0ff00)

/* MPIC_INT_IDRX : Register Bits Masks Definitions */
#define MPIC_INT_IDRX_SEL_OUT				(0x0000000f)
#define MPIC_INT_IDRX_RESERVED				(0xfffffff0)

/* MPIC_INT_DAR : Register Bits Masks Definitions */
#define MPIC_INT_DAR_A					(0x0000000f)
#define MPIC_INT_DAR_RESERVED				(0xfffffff0)

/* MPIC_INT_DVPRX : Register Bits Masks Definitions */
#define MPIC_INT_DVPRX_VECTOR				(0x000000ff)
#define MPIC_INT_DVPRX_PRIORITY				(0x000f0000)
#define MPIC_INT_DVPRX_A				(0x40000000)
#define MPIC_INT_DVPRX_M				(0x80000000)
#define MPIC_INT_DVPRX_RESERVED				(0x3ff0ff00)

/* MPIC_INT_DDRX : Register Bits Masks Definitions */
#define MPIC_INT_DDRX_SEL_OUT				(0x0000000f)
#define MPIC_INT_DDRX_RESERVED				(0xfffffff0)

/* MPIC_INT_DMRX : Register Bits Masks Definitions */
#define MPIC_INT_DMRX_M					(0xffffffff)

/* MPIC_INT_MBRX : Register Bits Masks Definitions */
#define MPIC_INT_MBRX_M					(0xffffffff)

/* MPIC_INT_MBVPRX : Register Bits Masks Definitions */
#define MPIC_INT_MBVPRX_VECTOR				(0x000000ff)
#define MPIC_INT_MBVPRX_PRIORITY			(0x000f0000)
#define MPIC_INT_MBVPRX_A				(0x40000000)
#define MPIC_INT_MBVPRX_M				(0x80000000)
#define MPIC_INT_MBVPRX_RESERVED			(0x3ff0ff00)

/* MPIC_INT_MBDRX : Register Bits Masks Definitions */
#define MPIC_INT_MBDRX_SEL_OUT				(0x0000000f)
#define MPIC_INT_MBDRX_RESERVED				(0xfffffff0)

/* MPIC_INT_TASKPX : Register Bits Masks Definitions */
#define MPIC_INT_TASKPX_TASKP				(0x0000000f)
#define MPIC_INT_TASKPX_RESERVED			(0xfffffff0)

/* MPIC_INT_VECTORX : Register Bits Masks Definitions */
#define MPIC_INT_VECTORX_VECTOR				(0x000000ff)
#define MPIC_INT_VECTORX_LS_VECTOR			(0xff000000)
#define MPIC_INT_VECTORX_RESERVED			(0x00ffff00)

/* MPIC_INT_EOIX : Register Bits Masks Definitions */
#define MPIC_INT_EOIX_EOI				(0x000000ff)
#define MPIC_INT_EOIX_RESERVED				(0xffffff00)

/* MPIC_INT_CSRX : Register Bits Masks Definitions */
#define MPIC_INT_CSRX_P					(0x00000001)
#define MPIC_INT_CSRX_S					(0x00000002)
#define MPIC_INT_CSRX_RESERVED				(0xfffffffc)

#endif /* _TS_MPIC_H_  */
