/*
 * (C) Copyright 2007 Tundra Semiconductor Corp.
 * http://www.tundra.com/Support/SupportForm.cfm
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

/*-----------------------------------------------------------------------------
* FILENAME: ts_sdc.h
*
* DESCRIPTION: Header file contains the TSI110 SDC port register definitions
*				and bitmasks
* HISTORY:
*
*    Rev. Date           Author          Description
*    ---- ------------   -------------   --------------------------------------
*         Apr 27, 2007   Jason McKenna   Improve formatting
*         Mar 14, 2007   Jason McKenna   Original release.
*----------------------------------------------------------------------------*/

#ifndef _TS_SDC_H_
#define _TS_SDC_H_

/* **********************************************/
/* SDC : Register address offset definitions    */
/* **********************************************/
#define SD_CTRL							(0x00000000)
#define SD_STATUS						(0x00000004)
#define SD_TIMING						(0x00000008)
#define SD_REFRESH						(0x0000000c)
#define SD_INT_STATUS						(0x00000010)
#define SD_INT_ENABLE						(0x00000014)
#define SD_INT_SET						(0x00000018)

#define MAX_SD_DX 2
#define SD_DX_CTRL(x) (0x20 + x*0x4)
#define SD_DX_BAR(x)  (0x28 + x*0x4)

#define SD_PB_ADDR_ERR_LO					(0x00000050)
#define SD_PB_ADDR_ERR_HI					(0x00000054)
#define SD_OCN_ADDR_ERR_LO					(0x00000058)
#define SD_OCN_ADDR_ERR_HI					(0x0000005c)
#define SD_ODT_CFG						(0x00000080)
#define SD_ODT_WRITE_PATTERN					(0x00000090)
#define SD_ODT_READ_PATTERN					(0x00000098)
#define SD_OCD_IA_CTRL						(0x000000a0)
#define SD_OCD_IA_STATUS					(0x000000a4)
#define SD_SINT_STATUS						(0x0000010c)

#define MAX_SD_DQS	18
#define SD_DQSX_DELAY(x) (0x200+ x*0x4)

#define SD_FB_DELAY						(0x00000248)
#define SD_ADV_CLK_DELAY					(0x0000024c)
#define SD_DLL_STATUS						(0x00000250)
#define SD_I2C_CTRL1						(0x00000400)
#define SD_I2C_CTRL2						(0x00000404)
#define SD_I2C_RD_DATA						(0x00000408)
#define SD_I2C_WRT_DATA						(0x0000040c)


/* **********************************************/
/* SDC : Register Bit Masks and Reset Values    */
/*           definitions for every register     */
/* **********************************************/

/* SD_CTRL : Register Bits Masks Definitions */
#define SD_CTRL_MEM_PRESERVE					(0x00000001)
#define SD_CTRL_OCN_EN						(0x00000010)
#define SD_CTRL_PB_EN						(0x00000020)
#define SD_CTRL_PB_SLOWER					(0x00000040)
#define SD_CTRL_RPW_DISABLE					(0x00000080)
#define SD_CTRL_PORT_ARB					(0x00000300)
#define SD_CTRL_FAST_INIT					(0x00010000)
#define SD_CTRL_EMULATION_MODE					(0x00100000)
#define SD_CTRL_SELF_RFSH_DLY					(0x0f000000)
#define SD_CTRL_SELF_RFSH					(0x10000000)
#define SD_CTRL_PWR_DWN						(0x20000000)
#define SD_CTRL_WAKE						(0x40000000)
#define SD_CTRL_ENABLE						(0x80000000)
#define SD_CTRL_RESERVED					(0x00eefc0e)

/* SD_STATUS : Register Bits Masks Definitions */
#define SD_STATUS_INIT_CMPLT					(0x00000001)
#define SD_STATUS_SDRAM_STATE					(0x00000006)
#define SD_STATUS_RESERVED					(0xfffffff8)

/* SD_TIMING : Register Bits Masks Definitions */
#define SD_TIMING_T_RFC						(0x0000001f)
#define SD_TIMING_T_WR						(0x000000e0)
#define SD_TIMING_T_RP						(0x00000700)
#define SD_TIMING_T_RCD						(0x00007000)
#define SD_TIMING_T_RAS						(0x000f0000)
#define SD_TIMING_CL						(0x07000000)
#define SD_TIMING_DIMM_TYPE					(0x10000000)
#define SD_TIMING_RESERVED					(0xe8f08800)

/* SD_REFRESH : Register Bits Masks Definitions */
#define SD_REFRESH_T						(0x0000ffff)
#define SD_REFRESH_RESERVED					(0xffff0000)

/* SD_INT_STATUS : Register Bits Masks Definitions */
#define SD_INT_STATUS_I2C_INT					(0x00000001)
#define SD_INT_STATUS_OCN_TEA_INT				(0x00000002)
#define SD_INT_STATUS_OCN_AE_INT				(0x00000004)
#define SD_INT_STATUS_PB_AE_INT					(0x00000008)
#define SD_INT_STATUS_RESERVED					(0xfffffff0)

/* SD_INT_ENABLE : Register Bits Masks Definitions */
#define SD_INT_ENABLE_I2C_EN					(0x00000001)
#define SD_INT_ENABLE_OCN_TEA_EN				(0x00000002)
#define SD_INT_ENABLE_OCN_AE_EN					(0x00000004)
#define SD_INT_ENABLE_PB_AE_EN					(0x00000008)
#define SD_INT_ENABLE_RESERVED					(0xfffffff0)

/* SD_INT_SET : Register Bits Masks Definitions */
#define SD_INT_SET_OCN_TEA_SET					(0x00000002)
#define SD_INT_SET_OCN_AE_SET					(0x00000004)
#define SD_INT_SET_PB_AE_SET					(0x00000008)
#define SD_INT_SET_RESERVED					(0xfffffff1)

/* SD_DX_CTRL : Register Bits Masks Definitions */
#define SD_DX_CTRL_ENABLE					(0x00000001)
#define SD_DX_CTRL_ADDR_MODE					(0x000000f0)
#define SD_DX_CTRL_NRANK					(0x00000100)
#define SD_DX_CTRL_NBANK					(0x00001000)
#define SD_DX_CTRL_AUTO_PRECHARGE				(0x00010000)
#define SD_DX_CTRL_MEM_WIDTH					(0x00100000)
#define SD_DX_CTRL_CLK_DISABLE					(0x07000000)
#define SD_DX_CTRL_RBC						(0x10000000)
#define SD_DX_CTRL_RWMASK					(0x171111f1)
#define SD_DX_CTRL_RESERVED					(0xe8eeee0e)

/* SD_DX_BAR : Register Bits Masks Definitions */
#define SD_DX_BAR_ADDR						(0x00000fff)
#define SD_DX_BAR_MASK						(0x0fff0000)
#define SD_DX_BAR_RESERVED					(0xf000f000)

/* SD_PB_ADDR_ERR_LO : Register Bits Masks Definitions */
#define SD_PB_ADDR_ERR_LO_EA					(0xffffffff)
#define SD_PB_ADDR_ERR_LO_RESERVED				(0x00000000)

/* SD_PB_ADDR_ERR_HI : Register Bits Masks Definitions */
#define SD_PB_ADDR_ERR_HI_EA					(0x000000ff)
#define SD_PB_ADDR_ERR_HI_RESERVED				(0xffffff00)

/* SD_OCN_ADDR_ERR_LO : Register Bits Masks Definitions */
#define SD_OCN_ADDR_ERR_LO_EA					(0xffffffff)

/* SD_OCN_ADDR_ERR_HI : Register Bits Masks Definitions */
#define SD_OCN_ADDR_ERR_HI_EA					(0x000000ff)
#define SD_OCN_ADDR_ERR_HI_RESERVED				(0xffffff00)

/* SD_ODT_CFG : Register Bits Masks Definitions */
#define SD_ODT_CFG_LOCAL_RTT					(0x00000003)
#define SD_ODT_CFG_D0_RTT					(0x00000300)
#define SD_ODT_CFG_D1_RTT					(0x00003000)
#define SD_ODT_CFG_FB_RTT					(0x00030000)
#define SD_ODT_CFG_RESERVED					(0xfffcccfc)

/* SD_ODT_WRITE_PATTERN : Register Bits Masks Definitions */
#define SD_ODT_WRITE_PATTERN_D0_R0_PAT				(0x0000000f)
#define SD_ODT_WRITE_PATTERN_D0_R1_PAT				(0x00000f00)
#define SD_ODT_WRITE_PATTERN_D1_R0_PAT				(0x000f0000)
#define SD_ODT_WRITE_PATTERN_D1_R1_PAT				(0x0f000000)
#define SD_ODT_WRITE_PATTERN_RESERVED				(0xf0f0f0f0)

/* SD_ODT_READ_PATTERN : Register Bits Masks Definitions */
#define SD_ODT_READ_PATTERN_D0_R0_PAT				(0x0000000f)
#define SD_ODT_READ_PATTERN_D0_R1_PAT				(0x00000f00)
#define SD_ODT_READ_PATTERN_D1_R0_PAT				(0x000f0000)
#define SD_ODT_READ_PATTERN_D1_R1_PAT				(0x0f000000)
#define SD_ODT_READ_PATTERN_RESERVED				(0xf0f0f0f0)

/* SD_OCD_IA_CTRL : Register Bits Masks Definitions */
#define SD_OCD_IA_CTRL_ADJUST_CODE				(0x0000000f)
#define SD_OCD_IA_CTRL_PART_SELECT				(0x00001f00)
#define SD_OCD_IA_CTRL_RANK_SELECT				(0x00010000)
#define SD_OCD_IA_CTRL_DIMM_SELECT				(0x00100000)
#define SD_OCD_IA_CTRL_PART_WIDTH				(0x03000000)
#define SD_OCD_IA_CTRL_RESERVED					(0xfceee0f0)

/* SD_OCD_IA_STATUS : Register Bits Masks Definitions */
#define SD_OCD_IA_STATUS_READY					(0x00000001)
#define SD_OCD_IA_STATUS_RESERVED				(0xfffffffe)

/* SD_SINT_STATUS : Register Bits Masks Definitions */
#define SD_SINT_STATUS_OCN_TEA_INT				(0x00000002)
#define SD_SINT_STATUS_OCN_AE_INT				(0x00000004)
#define SD_SINT_STATUS_PB_AE_INT				(0x00000008)
#define SD_SINT_STATUS_RESERVED					(0xfffffff1)

/* SD_DQS0_DELAY : Register Bits Masks Definitions */
#define SD_DQSX_DELAY_DLL_OFFSET				(0x000000ff)
#define SD_DQSX_DELAY_RESERVED					(0xffffff00)

/* SD_FB_DELAY : Register Bits Masks Definitions */
#define SD_FB_DELAY_DLL_OFFSET					(0x000000ff)
#define SD_FB_DELAY_RESERVED					(0xffffff00)

/* SD_ADV_CLK_DELAY : Register Bits Masks Definitions */
#define SD_ADV_CLK_DELAY_DLL_OFFSET				(0x000000ff)
#define SD_ADV_CLK_DELAY_RESERVED				(0xffffff00)

/* SD_DLL_STATUS : Register Bits Masks Definitions */
#define SD_DLL_STATUS_DLL_LOCKED				(0x000fffff)
#define SD_DLL_STATUS_RESERVED					(0xfff00000)

/* SD_I2C_CTRL1 : Register Bits Masks Definitions */
#define SD_I2C_CTRL1_DEVCODE					(0x0000000f)
#define SD_I2C_CTRL1_PAGE_SELECT				(0x00000700)
#define SD_I2C_CTRL1_I2C_ADDR					(0x00ff0000)
#define SD_I2C_CTRL1_WR_EN					(0x01000000)
#define SD_I2C_CTRL1_RESERVED					(0xfe00f8f0)

/* SD_I2C_CTRL2 : Register Bits Masks Definitions */
#define SD_I2C_CTRL2_SIZE					(0x00000003)
#define SD_I2C_CTRL2_LANE					(0x0000000c)
#define SD_I2C_CTRL2_MultiByte					(0x00000010)
#define SD_I2C_CTRL2_START					(0x00000100)
#define SD_I2C_CTRL2_WR_STATUS					(0x00010000)
#define SD_I2C_CTRL2_RD_STATUS					(0x00020000)
#define SD_I2C_CTRL2_I2C_TO_ERR					(0x04000000)
#define SD_I2C_CTRL2_I2C_CMPLT					(0x10000000)
#define SD_I2C_CTRL2_RESERVED					(0xebfcfee0)


/* SD_I2C_RD_DATA : Register Bits Masks Definitions */
#define SD_I2C_RD_DATA_I2C_RD_BYTE0				(0x000000ff)
#define SD_I2C_RD_DATA_I2C_RD_BYTE1				(0x0000ff00)
#define SD_I2C_RD_DATA_I2C_RD_BYTE2				(0x00ff0000)
#define SD_I2C_RD_DATA_I2C_RD_BYTE3				(0xff000000)

/* SD_I2C_WRT_DATA : Register Bits Masks Definitions */
#define SD_I2C_WRT_DATA_I2C_WRT_BYTE0				(0x000000ff)
#define SD_I2C_WRT_DATA_I2C_WRT_BYTE1				(0x0000ff00)
#define SD_I2C_WRT_DATA_I2C_WRT_BYTE2				(0x00ff0000)
#define SD_I2C_WRT_DATA_I2C_WRT_BYTE3				(0xff000000)

#endif /* _TS_SDC_H_  */
