/*
 * (C) Copyright 2007 Tundra Semiconductor Corp.
 * http://www.tundra.com/Support/SupportForm.cfm
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

/*-----------------------------------------------------------------------------
* FILENAME: tsi_110.h
*
* DESCRIPTION: Header file for the Tsi110: Host Bridge for PowerPC.
*
* HISTORY:
*
*    Rev. Date           Author          Description
*    ---- ------------   -------------   --------------------------------------
*         Apr 27, 2007   Jason McKenna   Improve formatting
*         Mar 14, 2007   Jason McKenna   Original release.
*----------------------------------------------------------------------------*/

#ifndef _TSI110_H_
#define _TSI110_H_

#define TSI110_CSR_BASE_RST	(0xc0000000)

#ifndef TSI110_CSR_BASE
#define TSI110_CSR_BASE		TSI110_CSR_BASE_RST
#endif


/****************************************************************************
 * Functional blocks offsets within Tsi110 register space
 */

#define TSI110_HLP_OFFSET	(0x0000)  /* HLP Interface Block */
#define TSI110_PCI_OFFSET	(0x1000)  /* PCI/PCI-X Interface Block */
#define TSI110_CG_OFFSET	(0x2000)  /* Clock Generator Block */
#define TSI110_PB_OFFSET	(0x3000)  /* Processor Bus Interface Block */
#define TSI110_SDC_OFFSET	(0x4000)  /* SDRAM Memory Controller Block */
#define TSI110_DMA_OFFSET	(0x5000)  /* DMA Block */
#define TSI110_GIGE_OFFSET	(0x6000)  /* Gigabit Eth. Controller Block */
#define TSI110_I2C_OFFSET	(0x7000)  /* I2C Interface Block */
#define TSI110_MPIC_OFFSET	(0x7400)  /* Interrupt Controller */
#define TSI110_UART0_OFFSET	(0x7800)  /* UART 0 */
#define TSI110_GPIO_OFFSET	(0x7A00)  /* GPIO Port */
#define TSI110_UART1_OFFSET	(0x7C00)  /* UART 1 */

/*============================================================================
 * Block identifications used by Tsi110 resisters access macro (defined below)
 */

#define BL_HLP			TSI110_HLP_OFFSET
#define BL_PCI			TSI110_PCI_OFFSET
#define BL_CLKG			TSI110_CG_OFFSET
#define BL_PB			TSI110_PB_OFFSET
#define BL_SDC			TSI110_SDC_OFFSET
#define BL_DMA(x)		(TSI110_DMA_OFFSET + (x)*0x100)
#define BL_GIGE(x)		(TSI110_GIGE_OFFSET + (x)*0x400)
#define BL_I2C			TSI110_I2C_OFFSET
#define BL_MPIC			TSI110_MPIC_OFFSET
#define BL_UART(x)		(TSI110_UART0_OFFSET + (x)*0x400)
#define BL_GPIO			TSI110_GPIO_OFFSET


/*============================================================================
 * Macro to read/write from/to Tsi110 registers.
 *
 * Definitions of individual block specific register offsets are provided in
 * separate include files for each block.
 *
 * Examples:
 *   1. Read status register of DMA channel 1:
 *         reg_value = *TSI110_REG_PTR(BL_DMA(1), DMA_CHX_GCSR);
 *
 *   2. Set all four dorbell bits in MPICs doorbell activation register:
 *         *TSI110_REG_PTR(BL_MPIC, MPIC_INT_DAR) = 0x000F;
 *
 */

#define TSI110_REG_PTR(blk,reg) \
	((volatile unsigned long *)(TSI110_CSR_BASE + (blk) + (reg)))

#endif  /* _TSI110_H_ */

